"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const es_1 = __importDefault(require("jimp/es"));
const XbrzImageFilter_1 = require("./XbrzImageFilter");
class Image {
    constructor(width, height, data) {
        this.width = width;
        this.height = height;
        this.data = data;
    }
    getPixelIndex(x, y) {
        return x + (y * this.width);
    }
    blit(source, x, y) {
        for (let curX = 0; curX < source.width; curX++) {
            for (let curY = 0; curY < source.height; curY++) {
                const value = source.data[source.getPixelIndex(curX, curY)];
                this.data[this.getPixelIndex(curX + x, curY + y)] = value;
            }
        }
    }
    getJimpImage() {
        return __awaiter(this, void 0, void 0, function* () {
            const image = yield es_1.default.create(this.width, this.height);
            this.data.forEach((d, i) => {
                image.bitmap.data.writeUInt32BE(d, i * 4);
            });
            return image;
        });
    }
    // Filters
    applyFilter(filter) {
        return filter.apply(this);
    }
    applyXbrzUpscaling(scale = 4) {
        return this.applyFilter(new XbrzImageFilter_1.XbrzImageFilter(scale));
    }
    // Output
    toFile(path) {
        return __awaiter(this, void 0, void 0, function* () {
            const image = yield this.getJimpImage();
            yield image.writeAsync(path);
        });
    }
    toDataUrl() {
        return __awaiter(this, void 0, void 0, function* () {
            const image = yield this.getJimpImage();
            return image.getBase64Async('image/png');
        });
    }
}
exports.Image = Image;
