"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const IndexedImageBase_1 = require("./IndexedImageBase");
class IndexedImage extends IndexedImageBase_1.IndexedImageBase {
    constructor(width, height, design) {
        super(width, height);
        this._colorIndexes = new Uint8Array(this.dataSize());
        this.design = design;
    }
    get colorPalette() {
        if (!this.design) {
            throw new Error('Missing design');
        }
        return this.design.colorPalette;
    }
    getColorIndexAt(x, y) {
        this.validateCoordinates(x, y);
        return this._colorIndexes[this.getPixelIndex(x, y)];
    }
    setColorIndexAt(x, y, value) {
        this.validateCoordinates(x, y);
        this._colorIndexes[this.getPixelIndex(x, y)] = value;
    }
    get colorIndexes() { return this._colorIndexes; }
    set colorIndexes(value) {
        this.validateDataSize(value);
        this._colorIndexes = value;
    }
}
exports.IndexedImage = IndexedImage;
